# PyDiderotLibs
Afin de faciliter l'apprentissage de python dans l'enseignement secondaire, les enseignants de mathématiques du lycée Diderot à Marseille construisent quelques librairies qui ont pour objectif de cacher certaines difficultés liées au langage de programmation afin de pouvoir cibler certains points pédagogiques. 

La documentation est disponible sur [readthedocs](https://pydiderotlibs.readthedocs.io).

- [repere](/graphique/): Permet l'affichage d'un repère du plan interactif (zoom, déplacer).
- [entree](/entree/): Fonctions d'entrées utilisateur avec des fenêtres tkinter.
- [lycee](/lycee/) : Regroupe les fonctions principales que sont amenés à utiliser les élèves de lycée en mathématiques (toutes filières confondues).
- [graphique](/graphique): Permet l'affichage d'une fenêtre graphique dynamique et une gestion simplifiée des entrées clavier et souris.
